@@ -836,6 +836,22 @@ Reason:
         <source>Invalid Version</source>
         <translation>無效版本</translation>
     </message>
+    <message>
+        <source>No Component</source>
+        <translation>沒有元件</translation>
+    </message>
+    <message>
+        <source>Invalid Component</source>
+        <translation>元件無效</translation>
+    </message>
+    <message>
+        <source>No Version</source>
+        <translation>沒有版本</translation>
+    </message>
+    <message>
+        <source>Invalid Version</source>
+        <translation>版本無效</translation>
+    </message>
     <message>
         <source>Filter Exists</source>
         <translation>篩選器存在</translation>
@@ -1011,6 +1027,10 @@ Reason:
         <source>Attributes:</source>
         <translation>屬性：</translation>
     </message>
+    <message>
+        <source>Versions:</source>
+        <translation>版本：</translation>
+    </message>
     <message>
         <source>1</source>
         <translation>1</translation>
